Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ControllerContext ¶
type ControllerContext struct {
RootContext context.Context
Client client.Client
Log logr.Logger
EventRecorder record.EventRecorder
// contains filtered or unexported fields
}
ControllerContext contains structures shared with all the controllers of the application.
func (*ControllerContext) GetProvider ¶
func (ctx *ControllerContext) GetProvider(name string, provider *Provider) bool
GetProvider returns the provider with the registered name, if any.
func (*ControllerContext) RemoveProvider ¶
func (ctx *ControllerContext) RemoveProvider(name string)
RemoveProvider removed the provider with the given name from the global map of registered providers.
func (*ControllerContext) SetProvider ¶
func (ctx *ControllerContext) SetProvider(name string, provider Provider)
SetProvider registers a new provider with the given name.
Click to show internal directories.
Click to hide internal directories.